{
    PLAYMUS:  A test application for the SDL mixer library.
    Copyright (C) 1997-1999  Sam Lantinga

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    Sam Lantinga
    5635-34 Springhouse Dr.
    Pleasanton, CA 94588 (USA)
    slouken@devolution.com
}

uses dos,crt,Sdl,Sdl_Mixer,SDL_types,SDL_audio;

var
audio_open:longint;
music:Mix_Music;
next_track:Longint;
n:string;
GoodBye:Boolean;

Procedure CleanUp;
begin
	if( Mix_PlayingMusic>0 ) then begin
		Mix_FadeOutMusic(1500);
		Delay(1500);
	end;
	if ( music<>Nil ) then begin
		Mix_FreeMusic(music);
		music := Nil;
	end;
	if ( audio_open>0 ) then begin
		Mix_CloseAudio;
		audio_open := 0;
	end;
	SDL_Quit;
end;

Procedure Usage;
begin
	Writeln('Usage: ',paramstr(0),' [-i] |-l] [-8] [-r rate] [-b buffers] [-s] <musicfile>');
end;

Procedure Menu;
var buf:char;
begin
        GotoXY(1,2);
        if keypressed then begin
          buf:=UpCase(readkey);
          if (buf='P') then Mix_PauseMusic();
	  if (buf='R') then Mix_ResumeMusic();
          if (buf='H') then Mix_HaltMusic();
          if (buf='Q') then GoodBye:=True;
        end;
	Write('Music playing: ');
        if Mix_PlayingMusic>0 then write('yes') else write('no');
        Write(' Paused: ');
	if Mix_PausedMusic>0 then writeln('yes') else writeln('no');
end;

var
	audio_rate:Longint;
	audio_format:Uint16;
	audio_channels:Longint;
	audio_buffers:longint;
	looping:longint;
	interactive:longint;
	i:longint;

begin
	{ Initialize variables }
	audio_rate := 22050;
	audio_format := AUDIO_S16;
	audio_channels := 2;
	audio_buffers := 4096;

	{ Check command line usage }
	for i:=1 to paramcount do begin
		if (paramstr(i)='-r') then begin
			inc(i);
			val(paramstr(i),audio_rate);
		end else
		if (paramstr(i)='-b') then begin
			inc(i);
			val(paramstr(i),audio_buffers);
		end else
		if (paramstr(i)='-m') then
			audio_channels := 1
		else
		if (paramstr(i)='-l') then 
			looping := -1
		else
		if (paramstr(i)='-i') then
			interactive := 1
		else
		if (paramstr(i)='-8') then
			audio_format := AUDIO_U8;
	end;
	if ( paramstr(i)='') then begin
		Usage;
		Halt(1);
	end;

	{ Initialize the SDL library }
	if ( SDL_Init(SDL_INIT_AUDIO) < 0 ) then begin
		Writeln('Couldn''t initialize SDL');
		Halt(255);
	end;

	{ Open the audio device }
	if (Mix_OpenAudio(audio_rate, audio_format, audio_channels, audio_buffers) < 0) then begin
		Writeln('Couldn''t open audio');
		Halt(2)
	end else begin
		Mix_QuerySpec(audio_rate, audio_format, audio_channels);
		Write('Opened audio at ',audio_rate,' Hz ',
                (audio_format and $FF),' bit ');
                if (audio_channels > 1) then Write('stereo') else write('mono');
                Writeln(' ',audio_buffers);
	end;
	audio_open := 1;

	{ Set the external music player, if any }
        n:=getenv('MUSIC_CMD');
	Mix_SetMusicCMD(@n[1]);

	while (paramstr(i)>'') do begin
		next_track := 0;
		
		{ Load the requested music file }
                n:=paramstr(i)+#0;
		music := Mix_LoadMUS(@n[1]);
		if ( music = Nil ) then begin
			Writeln('Couldn''t load ',paramstr(i));
			Halt(2);
		end;
		
		{ Play and then exit }
		Writeln('Playing ',paramstr(i));
		Mix_FadeInMusic(music,looping,2000);
                GoodBye:=false;
                ClrScr;
                GotoXY(1,1);
          	Writeln('Available commands: (p)ause (r)esume (h)alt (q)uit > ');

		while GoodBye=false do begin
                	if(interactive>0) then
				Menu()
			else
				Delay(100);
		end;
                {Mix_FreeMusic(music);}
                exit;
	end;
	CleanUp;
end.
