{
    PLAYWAVE:  A test application for the SDL mixer library.
    Copyright (C) 1997-1999  Sam Lantinga

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    Sam Lantinga
    5635-34 Springhouse Dr.
    Pleasanton, CA 94588 (USA)
    slouken@devolution.com
}

uses crt,Sdl,Sdl_Mixer,SDL_types,SDL_audio;


var audio_open:Longint;
wave:Mix_Chunk;
GoodBye:Boolean;

Procedure CleanUp;
begin
	if ( @wave>nil ) then begin
		Mix_FreeChunk(wave);
		{wave:='';}
	end;
	if ( audio_open>0 ) then begin
		Mix_CloseAudio;
		audio_open:= 0;
	end;
	SDL_Quit;
end;

Procedure Usage;
begin
	Writeln('Usage: ',paramstr(0),' [-8] [-r rate] [-l] [-m] <wavefile>');
end;
	
type	Uint16 = word;
var
	audio_rate :Longint;
	audio_format :Uint16;
	audio_channels :Longint;
	loops :Longint;
	i :Longint;
        n:string;
begin

	{ Initialize variables }
	audio_rate := MIX_DEFAULT_FREQUENCY;
	audio_format := MIX_DEFAULT_FORMAT;
	audio_channels := 2;

         Writeln(i,paramstr(paramcount));

	{ Check command line usage }
	for i:=1 to paramcount do begin
		if (paramstr(i)='-r') then begin
                        inc(i);
			val(paramstr(i),audio_rate);
		end else
		if (paramstr(i)='-m') then
			audio_channels := 1
		else
		if (paramstr(i)='-l') then
			loops := -1
		else
		if (paramstr(i)='-8') then
			audio_format := AUDIO_U8;
		{else begin
			Usage;
			Halt(1);
		end;}
	end;


	if ( paramstr(i)='') then begin
		Usage;
		Halt(1);
	end;

	{ Initialize the SDL library }
        Write('Initializing SDL...');
	if ( SDL_Init(SDL_INIT_AUDIO) < 0 ) then begin
		Writeln('Couldn''t initialize SDL: ');
		Halt(255);
	end;
        Writeln('Ok!');

	{ Open the audio device }
        Write('Opening audio device...');
	if (Mix_OpenAudio(audio_rate, audio_format, audio_channels, 4096) < 0) then begin
		Writeln('Couldn''t open audio: ');
		Halt(2);
	end else begin
                Writeln('Ok!');
                Write('Querying device...');
		Mix_QuerySpec(audio_rate, audio_format, audio_channels);
                Writeln('Ok!');
		Write('Opened audio at ',audio_rate,' Hz ',
                (audio_format and $FF),' bit ');
                if (audio_channels > 1) then write('stereo') else write('mono');
		if ( loops<>0 ) then 
		  Writeln(' (looping)')
		else 
                Writeln;

	end;
	audio_open := 1;

	{ Load the requested wave file }
        Write('Loading ',paramstr(i),'...');
        n:=paramstr(i)+#0;
        wave := Mix_LoadWAV(@n[1]);
        Writeln('Ok!');

	if ( wave = Nil ) then begin
		Writeln('Couldn''t load ',paramstr(i));
		Halt(2);
	end;

	{ Play and then exit }
        Writeln;
        Writeln('Press any key to stop playback');
        Writeln('Playing...');
	Mix_PlayChannel(0, wave, loops);
        GoodBye:=false;
	while ((Mix_Playing(0)>0) and (GoodBye=false)) do begin
                if keypressed then GoodBye:=true;
        end;
        if Mix_Playing(0)>0 then begin 
          Mix_HaltChannel(0);
          readkey;
        end;
        CleanUp;
end.
